# Changelog

Versions follow [semantic versioning](https://semver.org/>)
(``<major>.<minor>.<patch>``).

Changes in API will only be introduced in major versions with notes in the
deprecations section.

% Do not edit below this line, as the changelog is managed by towncrier

<!-- towncrier release notes start -->

## [0.8.1](https://github.com/jlorieau/geomancy/tree/0.8.1) - 2023-07-25


### Features

- [#9](https://github.com/jlorieau/geomancy/issues/9). Added the environment submodule and a CLI mechanism to load env files with -e/--env


### Improved Documentation

- [#7](https://github.com/jlorieau/geomancy/issues/7). Added base sphinx documentation
- [#8](https://github.com/jlorieau/geomancy/issues/8). Implement towncrier
